.. _speeds:

*****************************************************
Speed Plasma Parameters (`plasmapy.formulary.speeds`)
*****************************************************

.. currentmodule:: plasmapy.formulary.speeds

.. automodapi:: plasmapy.formulary.speeds

Examples
========

.. nbgallery::
    :caption: Examples

    /notebooks/formulary/distribution
    /notebooks/formulary/iter
    /notebooks/formulary/thermal_speed
